# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.recording_result import RecordingResult


class TestRecordingResult(unittest.TestCase):
    """RecordingResult unit test stubs"""

    def setUp(self):
        self.model = RecordingResult()

    def test_uri(self):
        """Test RecordingResult.uri"""

        self.model.uri = "TEST_STRING"
        assert self.model.uri == "TEST_STRING"

    def test_date_created(self):
        """Test RecordingResult.date_created"""

        self.model.date_created = "TEST_STRING"
        assert self.model.date_created == "TEST_STRING"

    def test_date_updated(self):
        """Test RecordingResult.date_updated"""

        self.model.date_updated = "TEST_STRING"
        assert self.model.date_updated == "TEST_STRING"

    def test_revision(self):
        """Test RecordingResult.revision"""
        self.model.revision = 1
        assert self.model.revision == 1

    def test_recording_id(self):
        """Test RecordingResult.recording_id"""

        self.model.recording_id = "TEST_STRING"
        assert self.model.recording_id == "TEST_STRING"

    def test_account_id(self):
        """Test RecordingResult.account_id"""

        self.model.account_id = "TEST_STRING"
        assert self.model.account_id == "TEST_STRING"

    def test_call_id(self):
        """Test RecordingResult.call_id"""

        self.model.call_id = "TEST_STRING"
        assert self.model.call_id == "TEST_STRING"

    def test_duration_sec(self):
        """Test RecordingResult.duration_sec"""
        self.model.duration_sec = 1
        assert self.model.duration_sec == 1

    def test_conference_id(self):
        """Test RecordingResult.conference_id"""

        self.model.conference_id = "TEST_STRING"
        assert self.model.conference_id == "TEST_STRING"


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.answered_by import AnsweredBy
from freeclimb.models.call_direction import CallDirection
from freeclimb.models.call_status import CallStatus
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class CallResult(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    CallResult
    """  # noqa: E501

    uri: Optional[StrictStr] = Field(
        default=None, description="The URI for this resource, relative to /apiserver."
    )
    date_created: Optional[StrictStr] = Field(
        default=None,
        description="The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).",
        alias="dateCreated",
    )
    date_updated: Optional[StrictStr] = Field(
        default=None,
        description="The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).",
        alias="dateUpdated",
    )
    revision: Optional[StrictInt] = Field(
        default=None,
        description="Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.",
    )
    call_id: Optional[StrictStr] = Field(
        default=None,
        description="String that uniquely identifies this Call resource.",
        alias="callId",
    )
    parent_call_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the Call that created this leg (child Call).",
        alias="parentCallId",
    )
    account_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the account that owns this Call.",
        alias="accountId",
    )
    var_from: Optional[StrictStr] = Field(
        default=None, description="Phone number that initiated this Call.", alias="from"
    )
    to: Optional[StrictStr] = Field(
        default=None, description="Phone number that received this Call."
    )
    phone_number_id: Optional[StrictStr] = Field(
        default=None,
        description="If the Call was inbound, this is the ID of the IncomingPhoneNumber that received the Call (DNIS). If the Call was outbound, this is the ID of the phone number from which the Call was placed (ANI).",
        alias="phoneNumberId",
    )
    call_status: Optional[CallStatus] = Field(default=None, alias="callStatus")
    start_time: Optional[StrictStr] = Field(
        default=None,
        description="Start time of the Call (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT). Empty if the Call has not yet been dialed.",
        alias="startTime",
    )
    connect_time: Optional[StrictStr] = Field(
        default=None,
        description="Time the Call was answered (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT). Empty if the Call has not yet been dialed.",
        alias="connectTime",
    )
    end_time: Optional[StrictStr] = Field(
        default=None,
        description="End time of the Call (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT). Empty if the Call did not complete successfully.",
        alias="endTime",
    )
    duration: Optional[StrictInt] = Field(
        default=None,
        description="Total length of the Call in seconds. Measures time between startTime and endTime. This value is empty for busy, failed, unanswered or ongoing Calls.",
    )
    connect_duration: Optional[StrictInt] = Field(
        default=None,
        description="Length of time that the Call was connected in seconds. Measures time between connectTime and endTime. This value is empty for busy, failed, unanswered or ongoing Calls.",
        alias="connectDuration",
    )
    direction: Optional[CallDirection] = None
    answered_by: Optional[AnsweredBy] = Field(default=None, alias="answeredBy")
    subresource_uris: Optional[Dict[str, Any]] = Field(
        default=None,
        description="The list of subresources for this Call. These include things like logs and recordings associated with the Call.",
        alias="subresourceUris",
    )
    application_id: Optional[StrictStr] = Field(
        default=None,
        description="ApplicationId associated with the Call.",
        alias="applicationId",
    )

    __properties: ClassVar[List[str]] = [
        "uri",
        "dateCreated",
        "dateUpdated",
        "revision",
        "callId",
        "parentCallId",
        "accountId",
        "from",
        "to",
        "phoneNumberId",
        "callStatus",
        "startTime",
        "connectTime",
        "endTime",
        "duration",
        "connectDuration",
        "direction",
        "answeredBy",
        "subresourceUris",
        "applicationId",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CallResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if call_id (nullable) is None
        # and model_fields_set contains the field
        if self.call_id is None and "call_id" in self.model_fields_set:
            _dict["callId"] = None

        # set to None if parent_call_id (nullable) is None
        # and model_fields_set contains the field
        if self.parent_call_id is None and "parent_call_id" in self.model_fields_set:
            _dict["parentCallId"] = None

        # set to None if account_id (nullable) is None
        # and model_fields_set contains the field
        if self.account_id is None and "account_id" in self.model_fields_set:
            _dict["accountId"] = None

        # set to None if var_from (nullable) is None
        # and model_fields_set contains the field
        if self.var_from is None and "var_from" in self.model_fields_set:
            _dict["from"] = None

        # set to None if to (nullable) is None
        # and model_fields_set contains the field
        if self.to is None and "to" in self.model_fields_set:
            _dict["to"] = None

        # set to None if phone_number_id (nullable) is None
        # and model_fields_set contains the field
        if self.phone_number_id is None and "phone_number_id" in self.model_fields_set:
            _dict["phoneNumberId"] = None

        # set to None if call_status (nullable) is None
        # and model_fields_set contains the field
        if self.call_status is None and "call_status" in self.model_fields_set:
            _dict["callStatus"] = None

        # set to None if start_time (nullable) is None
        # and model_fields_set contains the field
        if self.start_time is None and "start_time" in self.model_fields_set:
            _dict["startTime"] = None

        # set to None if connect_time (nullable) is None
        # and model_fields_set contains the field
        if self.connect_time is None and "connect_time" in self.model_fields_set:
            _dict["connectTime"] = None

        # set to None if end_time (nullable) is None
        # and model_fields_set contains the field
        if self.end_time is None and "end_time" in self.model_fields_set:
            _dict["endTime"] = None

        # set to None if duration (nullable) is None
        # and model_fields_set contains the field
        if self.duration is None and "duration" in self.model_fields_set:
            _dict["duration"] = None

        # set to None if connect_duration (nullable) is None
        # and model_fields_set contains the field
        if (
            self.connect_duration is None
            and "connect_duration" in self.model_fields_set
        ):
            _dict["connectDuration"] = None

        # set to None if direction (nullable) is None
        # and model_fields_set contains the field
        if self.direction is None and "direction" in self.model_fields_set:
            _dict["direction"] = None

        # set to None if answered_by (nullable) is None
        # and model_fields_set contains the field
        if self.answered_by is None and "answered_by" in self.model_fields_set:
            _dict["answeredBy"] = None

        # set to None if subresource_uris (nullable) is None
        # and model_fields_set contains the field
        if (
            self.subresource_uris is None
            and "subresource_uris" in self.model_fields_set
        ):
            _dict["subresourceUris"] = None

        # set to None if application_id (nullable) is None
        # and model_fields_set contains the field
        if self.application_id is None and "application_id" in self.model_fields_set:
            _dict["applicationId"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CallResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "uri": obj.get("uri"),
                "dateCreated": obj.get("dateCreated"),
                "dateUpdated": obj.get("dateUpdated"),
                "revision": obj.get("revision"),
                "callId": obj.get("callId"),
                "parentCallId": obj.get("parentCallId"),
                "accountId": obj.get("accountId"),
                "from": obj.get("from"),
                "to": obj.get("to"),
                "phoneNumberId": obj.get("phoneNumberId"),
                "callStatus": obj.get("callStatus"),
                "startTime": obj.get("startTime"),
                "connectTime": obj.get("connectTime"),
                "endTime": obj.get("endTime"),
                "duration": obj.get("duration"),
                "connectDuration": obj.get("connectDuration"),
                "direction": obj.get("direction"),
                "answeredBy": obj.get("answeredBy"),
                "subresourceUris": obj.get("subresourceUris"),
                "applicationId": obj.get("applicationId"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.percl_command import PerclCommand
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class Park(
    PerclCommand,
    populate_by_name=True,
    validate_assignment=True,
    protected_namespaces=(),
):
    """
    The `Park` command allows a caller to be put on hold.  You can provide hold music,messages,etc until ready to resume the call. Park is a terminal command.  Actions performed on the Call while on hold are provided in a PerCL script in response to the waitUrl property. Actions performed on the Call after it has been unparked (resumed) will be provided in a PerCL script in response to the actionUrl provided. A Call can be resumed in two ways -- REST API invocation or the Unpark percl command. No actions can be nested within Park and Park cannot be nested in any other actions.
    """  # noqa: E501

    wait_url: StrictStr = Field(
        description="Specifies a URL pointing to a PerCL script containing actions to be executed while the caller is Parked. Once the script returned by the waitUrl runs out of commands to execute, FreeClimb will re-request the waitUrl and start over, essentially looping the script requests indefinitely.",
        alias="waitUrl",
    )
    action_url: StrictStr = Field(
        description="A request is made to this URL when the Call is resumed, which can occur if the Call is resumed via the Unpark command, the REST API (POST to Call resource), or the caller hangs up. The PerCL script returned in response to the actionUrl will be executed on the resumed call.",
        alias="actionUrl",
    )
    notification_url: Optional[StrictStr] = Field(
        default=None,
        description="URL to be invoked when the Call is parked. The request to the URL contains the standard request parameters.",
        alias="notificationUrl",
    )
    command: StrictStr = "Park"

    __properties: ClassVar[List[str]] = [
        "command",
        "waitUrl",
        "actionUrl",
        "notificationUrl",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Park from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Park from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "command": obj.get("command"),
                "waitUrl": obj.get("waitUrl"),
                "actionUrl": obj.get("actionUrl"),
                "notificationUrl": obj.get("notificationUrl"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from importlib import import_module
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from freeclimb.models.add_to_conference import AddToConference
    from freeclimb.models.create_conference import CreateConference
    from freeclimb.models.dequeue import Dequeue
    from freeclimb.models.enqueue import Enqueue
    from freeclimb.models.get_digits import GetDigits
    from freeclimb.models.get_speech import GetSpeech
    from freeclimb.models.hangup import Hangup
    from freeclimb.models.out_dial import OutDial
    from freeclimb.models.park import Park
    from freeclimb.models.pause import Pause
    from freeclimb.models.play import Play
    from freeclimb.models.play_early_media import PlayEarlyMedia
    from freeclimb.models.record_utterance import RecordUtterance
    from freeclimb.models.redirect import Redirect
    from freeclimb.models.reject import Reject
    from freeclimb.models.remove_from_conference import RemoveFromConference
    from freeclimb.models.say import Say
    from freeclimb.models.send_digits import SendDigits
    from freeclimb.models.set_dtmf_pass_through import SetDTMFPassThrough
    from freeclimb.models.set_listen import SetListen
    from freeclimb.models.set_talk import SetTalk
    from freeclimb.models.sms import Sms
    from freeclimb.models.start_record_call import StartRecordCall
    from freeclimb.models.terminate_conference import TerminateConference
    from freeclimb.models.transcribe_utterance import TranscribeUtterance
    from freeclimb.models.unpark import Unpark


class PerclCommand(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    An individual command used in a PerCLScript.
    """  # noqa: E501

    command: Optional[StrictStr] = Field(
        default=None,
        description="Name of PerCL Command (this is automatically derived from mapping configuration and should not be manually supplied in any arguments)",
    )

    __properties: ClassVar[List[str]] = ["command"]

    # JSON field name that stores the object type
    __discriminator_property_name: ClassVar[str] = "command"

    # discriminator mappings
    __discriminator_value_class_map: ClassVar[Dict[str, str]] = {
        "AddToConference": "AddToConference",
        "CreateConference": "CreateConference",
        "Dequeue": "Dequeue",
        "Enqueue": "Enqueue",
        "GetDigits": "GetDigits",
        "GetSpeech": "GetSpeech",
        "Hangup": "Hangup",
        "OutDial": "OutDial",
        "Park": "Park",
        "Pause": "Pause",
        "Play": "Play",
        "PlayEarlyMedia": "PlayEarlyMedia",
        "RecordUtterance": "RecordUtterance",
        "Redirect": "Redirect",
        "Reject": "Reject",
        "RemoveFromConference": "RemoveFromConference",
        "Say": "Say",
        "SendDigits": "SendDigits",
        "SetDTMFPassThrough": "SetDTMFPassThrough",
        "SetListen": "SetListen",
        "SetTalk": "SetTalk",
        "Sms": "Sms",
        "StartRecordCall": "StartRecordCall",
        "TerminateConference": "TerminateConference",
        "TranscribeUtterance": "TranscribeUtterance",
        "Unpark": "Unpark",
    }

    @classmethod
    def get_discriminator_value(cls, obj: Dict[str, Any]) -> Optional[str]:
        """Returns the discriminator value (object type) of the data"""
        discriminator_value = obj[cls.__discriminator_property_name]
        if discriminator_value:
            return cls.__discriminator_value_class_map.get(discriminator_value)
        else:
            return None

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[
        Union[
            AddToConference,
            CreateConference,
            Dequeue,
            Enqueue,
            GetDigits,
            GetSpeech,
            Hangup,
            OutDial,
            Park,
            Pause,
            Play,
            PlayEarlyMedia,
            RecordUtterance,
            Redirect,
            Reject,
            RemoveFromConference,
            Say,
            SendDigits,
            SetDTMFPassThrough,
            SetListen,
            SetTalk,
            Sms,
            StartRecordCall,
            TerminateConference,
            TranscribeUtterance,
            Unpark,
        ]
    ]:
        """Create an instance of PerclCommand from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict[str, Any]) -> Optional[
        Union[
            AddToConference,
            CreateConference,
            Dequeue,
            Enqueue,
            GetDigits,
            GetSpeech,
            Hangup,
            OutDial,
            Park,
            Pause,
            Play,
            PlayEarlyMedia,
            RecordUtterance,
            Redirect,
            Reject,
            RemoveFromConference,
            Say,
            SendDigits,
            SetDTMFPassThrough,
            SetListen,
            SetTalk,
            Sms,
            StartRecordCall,
            TerminateConference,
            TranscribeUtterance,
            Unpark,
        ]
    ]:
        """Create an instance of PerclCommand from a dict"""
        # look up the object type based on discriminator mapping
        object_type = cls.get_discriminator_value(obj)
        if object_type == "AddToConference":
            return import_module(
                "freeclimb.models.add_to_conference"
            ).AddToConference.from_dict(obj)
        if object_type == "CreateConference":
            return import_module(
                "freeclimb.models.create_conference"
            ).CreateConference.from_dict(obj)
        if object_type == "Dequeue":
            return import_module("freeclimb.models.dequeue").Dequeue.from_dict(obj)
        if object_type == "Enqueue":
            return import_module("freeclimb.models.enqueue").Enqueue.from_dict(obj)
        if object_type == "GetDigits":
            return import_module("freeclimb.models.get_digits").GetDigits.from_dict(obj)
        if object_type == "GetSpeech":
            return import_module("freeclimb.models.get_speech").GetSpeech.from_dict(obj)
        if object_type == "Hangup":
            return import_module("freeclimb.models.hangup").Hangup.from_dict(obj)
        if object_type == "OutDial":
            return import_module("freeclimb.models.out_dial").OutDial.from_dict(obj)
        if object_type == "Park":
            return import_module("freeclimb.models.park").Park.from_dict(obj)
        if object_type == "Pause":
            return import_module("freeclimb.models.pause").Pause.from_dict(obj)
        if object_type == "Play":
            return import_module("freeclimb.models.play").Play.from_dict(obj)
        if object_type == "PlayEarlyMedia":
            return import_module(
                "freeclimb.models.play_early_media"
            ).PlayEarlyMedia.from_dict(obj)
        if object_type == "RecordUtterance":
            return import_module(
                "freeclimb.models.record_utterance"
            ).RecordUtterance.from_dict(obj)
        if object_type == "Redirect":
            return import_module("freeclimb.models.redirect").Redirect.from_dict(obj)
        if object_type == "Reject":
            return import_module("freeclimb.models.reject").Reject.from_dict(obj)
        if object_type == "RemoveFromConference":
            return import_module(
                "freeclimb.models.remove_from_conference"
            ).RemoveFromConference.from_dict(obj)
        if object_type == "Say":
            return import_module("freeclimb.models.say").Say.from_dict(obj)
        if object_type == "SendDigits":
            return import_module("freeclimb.models.send_digits").SendDigits.from_dict(
                obj
            )
        if object_type == "SetDTMFPassThrough":
            return import_module(
                "freeclimb.models.set_dtmf_pass_through"
            ).SetDTMFPassThrough.from_dict(obj)
        if object_type == "SetListen":
            return import_module("freeclimb.models.set_listen").SetListen.from_dict(obj)
        if object_type == "SetTalk":
            return import_module("freeclimb.models.set_talk").SetTalk.from_dict(obj)
        if object_type == "Sms":
            return import_module("freeclimb.models.sms").Sms.from_dict(obj)
        if object_type == "StartRecordCall":
            return import_module(
                "freeclimb.models.start_record_call"
            ).StartRecordCall.from_dict(obj)
        if object_type == "TerminateConference":
            return import_module(
                "freeclimb.models.terminate_conference"
            ).TerminateConference.from_dict(obj)
        if object_type == "TranscribeUtterance":
            return import_module(
                "freeclimb.models.transcribe_utterance"
            ).TranscribeUtterance.from_dict(obj)
        if object_type == "Unpark":
            return import_module("freeclimb.models.unpark").Unpark.from_dict(obj)

        raise ValueError(
            "PerclCommand failed to lookup discriminator value from "
            + json.dumps(obj)
            + ". Discriminator property name: "
            + cls.__discriminator_property_name
            + ", mapping: "
            + json.dumps(cls.__discriminator_value_class_map)
        )



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.webhook import Webhook
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class MessageDeliveryWebhook(
    Webhook, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    An SMS has been received by the platform and is being delivered to the smsUrl of the customer application that is associated with the destination number. A PerCL response will be ignored.
    """  # noqa: E501

    request_type: Optional[StrictStr] = Field(
        default=None,
        description="Value will be messageDelivery - An SMS message has been received by the platform and is being delivered to the customer application associated with the destination number.",
        alias="requestType",
    )
    account_id: Optional[StrictStr] = Field(
        default=None,
        description="Account ID associated with your account.",
        alias="accountId",
    )
    var_from: Optional[StrictStr] = Field(
        default=None,
        description="Phone number of the party that initiated the Call (in E.164 format).",
        alias="from",
    )
    to: Optional[StrictStr] = Field(
        default=None,
        description="Phone number provisioned to you and to which this Call is directed (in E.164 format).",
    )
    text: Optional[StrictStr] = Field(
        default=None, description="Body of the SMS message."
    )
    direction: Optional[StrictStr] = Field(
        default=None,
        description="Value will be inbound to indicate the receipt of a message into the FreeClimb platform.",
    )
    application_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the application to which the destination number is assigned.",
        alias="applicationId",
    )
    status: Optional[StrictStr] = Field(
        default=None,
        description="Value will be received to indicate that the platform has successfully received the incoming message.",
    )
    phone_number_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the destination phone number.",
        alias="phoneNumberId",
    )
    uri: Optional[StrictStr] = Field(
        default=None,
        description="The URI for this resource, relative to the API base URL",
    )

    __properties: ClassVar[List[str]] = [
        "requestType",
        "accountId",
        "from",
        "to",
        "text",
        "direction",
        "applicationId",
        "status",
        "phoneNumberId",
        "uri",
    ]

    @classmethod
    def deserialize(cls, payload: str) -> Optional[Self]:
        return cls.from_json(payload)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MessageDeliveryWebhook from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MessageDeliveryWebhook from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "requestType": obj.get("requestType"),
                "accountId": obj.get("accountId"),
                "from": obj.get("from"),
                "to": obj.get("to"),
                "text": obj.get("text"),
                "direction": obj.get("direction"),
                "applicationId": obj.get("applicationId"),
                "status": obj.get("status"),
                "phoneNumberId": obj.get("phoneNumberId"),
                "uri": obj.get("uri"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.call_status_webhook import CallStatusWebhook


class TestCallStatusWebhook(unittest.TestCase):
    """CallStatusWebhook unit test stubs"""

    def setUp(self):
        self.model = CallStatusWebhook()

    def test_request_type(self):
        """Test CallStatusWebhook.request_type"""

    def test_call_id(self):
        """Test CallStatusWebhook.call_id"""

        self.model.call_id = "TEST_STRING"
        assert self.model.call_id == "TEST_STRING"

    def test_account_id(self):
        """Test CallStatusWebhook.account_id"""

        self.model.account_id = "TEST_STRING"
        assert self.model.account_id == "TEST_STRING"

    def test_var_from(self):
        """Test CallStatusWebhook.var_from"""

        self.model.var_from = "TEST_STRING"
        assert self.model.var_from == "TEST_STRING"

    def test_to(self):
        """Test CallStatusWebhook.to"""

        self.model.to = "TEST_STRING"
        assert self.model.to == "TEST_STRING"

    def test_call_status(self):
        """Test CallStatusWebhook.call_status"""
        self.model.call_status = CallStatus.QUEUED
        assert self.model.call_status == CallStatus.QUEUED
        self.model.call_status = CallStatus.RINGING
        assert self.model.call_status == CallStatus.RINGING
        self.model.call_status = CallStatus.IN_PROGRESS
        assert self.model.call_status == CallStatus.IN_PROGRESS
        self.model.call_status = CallStatus.CANCELED
        assert self.model.call_status == CallStatus.CANCELED
        self.model.call_status = CallStatus.COMPLETED
        assert self.model.call_status == CallStatus.COMPLETED
        self.model.call_status = CallStatus.FAILED
        assert self.model.call_status == CallStatus.FAILED
        self.model.call_status = CallStatus.BUSY
        assert self.model.call_status == CallStatus.BUSY
        self.model.call_status = CallStatus.NO_ANSWER
        assert self.model.call_status == CallStatus.NO_ANSWER

    def test_call_ended_reason(self):
        """Test CallStatusWebhook.call_ended_reason"""
        self.model.call_ended_reason = CallEndedReason.BUSY
        assert self.model.call_ended_reason == CallEndedReason.BUSY
        self.model.call_ended_reason = CallEndedReason.FAILED
        assert self.model.call_ended_reason == CallEndedReason.FAILED
        self.model.call_ended_reason = CallEndedReason.NO_ANSWER
        assert self.model.call_ended_reason == CallEndedReason.NO_ANSWER
        self.model.call_ended_reason = CallEndedReason.CALL_CANCELED
        assert self.model.call_ended_reason == CallEndedReason.CALL_CANCELED
        self.model.call_ended_reason = CallEndedReason.FAR_END_HANGUP
        assert self.model.call_ended_reason == CallEndedReason.FAR_END_HANGUP
        self.model.call_ended_reason = CallEndedReason.APP_HANGUP
        assert self.model.call_ended_reason == CallEndedReason.APP_HANGUP
        self.model.call_ended_reason = CallEndedReason.APP_REJECT
        assert self.model.call_ended_reason == CallEndedReason.APP_REJECT
        self.model.call_ended_reason = CallEndedReason.APP_NO_PERCL
        assert self.model.call_ended_reason == CallEndedReason.APP_NO_PERCL
        self.model.call_ended_reason = CallEndedReason.APP_INVALID_PERCL
        assert self.model.call_ended_reason == CallEndedReason.APP_INVALID_PERCL
        self.model.call_ended_reason = CallEndedReason.CONFERENCE_TERMINATED
        assert self.model.call_ended_reason == CallEndedReason.CONFERENCE_TERMINATED
        self.model.call_ended_reason = CallEndedReason.CONFERENCE_EMPTIED
        assert self.model.call_ended_reason == CallEndedReason.CONFERENCE_EMPTIED
        self.model.call_ended_reason = CallEndedReason.REMOVED_FROM_CONFERENCE
        assert self.model.call_ended_reason == CallEndedReason.REMOVED_FROM_CONFERENCE
        self.model.call_ended_reason = CallEndedReason.MACHINE_DETECTED
        assert self.model.call_ended_reason == CallEndedReason.MACHINE_DETECTED
        self.model.call_ended_reason = CallEndedReason.WEBHOOK_FAILED
        assert self.model.call_ended_reason == CallEndedReason.WEBHOOK_FAILED
        self.model.call_ended_reason = CallEndedReason.WEBHOOK_INVALID_RESPONSE
        assert self.model.call_ended_reason == CallEndedReason.WEBHOOK_INVALID_RESPONSE
        self.model.call_ended_reason = CallEndedReason.VOICE_DISABLED
        assert self.model.call_ended_reason == CallEndedReason.VOICE_DISABLED
        self.model.call_ended_reason = CallEndedReason.CONFIG_ERROR_NO_APPLICATION
        assert (
            self.model.call_ended_reason == CallEndedReason.CONFIG_ERROR_NO_APPLICATION
        )
        self.model.call_ended_reason = CallEndedReason.CONFIG_ERROR_NO_VOICE_URL
        assert self.model.call_ended_reason == CallEndedReason.CONFIG_ERROR_NO_VOICE_URL
        self.model.call_ended_reason = CallEndedReason.MAX_REDIRECTS_ERROR
        assert self.model.call_ended_reason == CallEndedReason.MAX_REDIRECTS_ERROR
        self.model.call_ended_reason = CallEndedReason.PERCL_PROCESSING_ERROR
        assert self.model.call_ended_reason == CallEndedReason.PERCL_PROCESSING_ERROR
        self.model.call_ended_reason = CallEndedReason.INTERNAL_ERROR
        assert self.model.call_ended_reason == CallEndedReason.INTERNAL_ERROR
        self.model.call_ended_reason = CallEndedReason.GRPC_HANGUP
        assert self.model.call_ended_reason == CallEndedReason.GRPC_HANGUP
        self.model.call_ended_reason = CallEndedReason.MAX_DURATION
        assert self.model.call_ended_reason == CallEndedReason.MAX_DURATION

    def test_direction(self):
        """Test CallStatusWebhook.direction"""
        self.model.direction = CallDirection.INBOUND
        assert self.model.direction == CallDirection.INBOUND
        self.model.direction = CallDirection.OUTBOUND_API
        assert self.model.direction == CallDirection.OUTBOUND_API
        self.model.direction = CallDirection.OUTBOUND_DIAL
        assert self.model.direction == CallDirection.OUTBOUND_DIAL

    def test_conference_id(self):
        """Test CallStatusWebhook.conference_id"""

        self.model.conference_id = "TEST_STRING"
        assert self.model.conference_id == "TEST_STRING"

    def test_queue_id(self):
        """Test CallStatusWebhook.queue_id"""

        self.model.queue_id = "TEST_STRING"
        assert self.model.queue_id == "TEST_STRING"

    def test_deserialize(self):
        payload = '{ "requestType": "callStatus" }'
        assert isinstance(CallStatusWebhook.deserialize(payload), CallStatusWebhook)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.conference_result import ConferenceResult


class TestConferenceResult(unittest.TestCase):
    """ConferenceResult unit test stubs"""

    def setUp(self):
        self.model = ConferenceResult()

    def test_uri(self):
        """Test ConferenceResult.uri"""

        self.model.uri = "TEST_STRING"
        assert self.model.uri == "TEST_STRING"

    def test_date_created(self):
        """Test ConferenceResult.date_created"""

        self.model.date_created = "TEST_STRING"
        assert self.model.date_created == "TEST_STRING"

    def test_date_updated(self):
        """Test ConferenceResult.date_updated"""

        self.model.date_updated = "TEST_STRING"
        assert self.model.date_updated == "TEST_STRING"

    def test_revision(self):
        """Test ConferenceResult.revision"""
        self.model.revision = 1
        assert self.model.revision == 1

    def test_conference_id(self):
        """Test ConferenceResult.conference_id"""

        self.model.conference_id = "TEST_STRING"
        assert self.model.conference_id == "TEST_STRING"

    def test_account_id(self):
        """Test ConferenceResult.account_id"""

        self.model.account_id = "TEST_STRING"
        assert self.model.account_id == "TEST_STRING"

    def test_alias(self):
        """Test ConferenceResult.alias"""

        self.model.alias = "TEST_STRING"
        assert self.model.alias == "TEST_STRING"

    def test_play_beep(self):
        """Test ConferenceResult.play_beep"""
        self.model.play_beep = PlayBeep.ALWAYS
        assert self.model.play_beep == PlayBeep.ALWAYS
        self.model.play_beep = PlayBeep.NEVER
        assert self.model.play_beep == PlayBeep.NEVER
        self.model.play_beep = PlayBeep.ENTRY_ONLY
        assert self.model.play_beep == PlayBeep.ENTRY_ONLY
        self.model.play_beep = PlayBeep.EXIT_ONLY
        assert self.model.play_beep == PlayBeep.EXIT_ONLY

    def test_record(self):
        """Test ConferenceResult.record"""
        self.model.record = False
        assert self.model.record == False

    def test_status(self):
        """Test ConferenceResult.status"""
        self.model.status = ConferenceStatus.EMPTY
        assert self.model.status == ConferenceStatus.EMPTY
        self.model.status = ConferenceStatus.POPULATED
        assert self.model.status == ConferenceStatus.POPULATED
        self.model.status = ConferenceStatus.IN_PROGRESS
        assert self.model.status == ConferenceStatus.IN_PROGRESS
        self.model.status = ConferenceStatus.TERMINATED
        assert self.model.status == ConferenceStatus.TERMINATED

    def test_wait_url(self):
        """Test ConferenceResult.wait_url"""
        self.model.wait_url = "TEST_STRING"
        assert self.model.wait_url == "TEST_STRING"

    def test_action_url(self):
        """Test ConferenceResult.action_url"""
        self.model.action_url = "TEST_STRING"
        assert self.model.action_url == "TEST_STRING"

    def test_status_callback_url(self):
        """Test ConferenceResult.status_callback_url"""
        self.model.status_callback_url = "TEST_STRING"
        assert self.model.status_callback_url == "TEST_STRING"

    def test_subresource_uris(self):
        """Test ConferenceResult.subresource_uris"""
        object = None
        self.model.subresource_uris = object
        assert self.model.subresource_uris == object


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.call_direction import CallDirection
from freeclimb.models.call_status import CallStatus
from freeclimb.models.get_digits_reason import GetDigitsReason
from freeclimb.models.webhook import Webhook
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class GetDigitsWebhook(
    Webhook, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    A POST request with the following fields will be sent to the actionUrl provided in your GetDigits command.
    """  # noqa: E501

    request_type: Optional[StrictStr] = Field(
        default=None,
        description="Context or reason why this request is being made. Will be getDigits - The GetDigits command has completed and its actionUrl is being invoked.",
        alias="requestType",
    )
    call_id: Optional[StrictStr] = Field(
        default=None,
        description="Unique ID for this Call, generated by FreeClimb.",
        alias="callId",
    )
    account_id: Optional[StrictStr] = Field(
        default=None,
        description="Account ID associated with your account.",
        alias="accountId",
    )
    var_from: Optional[StrictStr] = Field(
        default=None,
        description="Phone number of the party that initiated the Call (in E.164 format).",
        alias="from",
    )
    to: Optional[StrictStr] = Field(
        default=None,
        description="Phone number provisioned to you and to which this Call is directed (in E.164 format).",
    )
    call_status: Optional[CallStatus] = Field(default=None, alias="callStatus")
    direction: Optional[CallDirection] = None
    conference_id: Optional[StrictStr] = Field(
        default=None, description="Unique ID of the Conference.", alias="conferenceId"
    )
    queue_id: Optional[StrictStr] = Field(
        default=None,
        description="This is only populated if the request pertains to a Queue. Otherwise, it is set to null.",
        alias="queueId",
    )
    digits: Optional[StrictStr] = Field(
        default=None,
        description="tring of digits entered by the Caller, excluding the terminating digit (if used). The string of digits will be replaced by 'xxxxx' when privacyMode is set to true",
    )
    reason: Optional[GetDigitsReason] = None
    parent_call_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the Call that created this leg (child call).",
        alias="parentCallId",
    )

    __properties: ClassVar[List[str]] = [
        "requestType",
        "callId",
        "accountId",
        "from",
        "to",
        "callStatus",
        "direction",
        "conferenceId",
        "queueId",
        "digits",
        "reason",
        "parentCallId",
    ]

    @classmethod
    def deserialize(cls, payload: str) -> Optional[Self]:
        return cls.from_json(payload)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GetDigitsWebhook from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if call_status (nullable) is None
        # and model_fields_set contains the field
        if self.call_status is None and "call_status" in self.model_fields_set:
            _dict["callStatus"] = None

        # set to None if direction (nullable) is None
        # and model_fields_set contains the field
        if self.direction is None and "direction" in self.model_fields_set:
            _dict["direction"] = None

        # set to None if queue_id (nullable) is None
        # and model_fields_set contains the field
        if self.queue_id is None and "queue_id" in self.model_fields_set:
            _dict["queueId"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GetDigitsWebhook from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "requestType": obj.get("requestType"),
                "callId": obj.get("callId"),
                "accountId": obj.get("accountId"),
                "from": obj.get("from"),
                "to": obj.get("to"),
                "callStatus": obj.get("callStatus"),
                "direction": obj.get("direction"),
                "conferenceId": obj.get("conferenceId"),
                "queueId": obj.get("queueId"),
                "digits": obj.get("digits"),
                "reason": obj.get("reason"),
                "parentCallId": obj.get("parentCallId"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.log_level import LogLevel
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class LogResult(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    LogResult
    """  # noqa: E501

    timestamp: Optional[StrictInt] = Field(
        default=None,
        description="Time that the log was generated. The time is represented as microseconds since the Unix Epoch.",
    )
    level: Optional[LogLevel] = None
    request_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the request associated with the log. The requestId is propagated across all logs generated by FreeClimb when processing a request.",
        alias="requestId",
    )
    account_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the account that this log was generated under.",
        alias="accountId",
    )
    call_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the Call associated with the log. Can be set to null if the log was generated without regard to a specific Call.",
        alias="callId",
    )
    message: Optional[StrictStr] = Field(
        default=None, description="A simple string describing the event being logged."
    )
    metadata: Optional[Dict[str, Any]] = Field(
        default=None,
        description="JSON document containing metadata about the event. Some log messages may include request and response header content in this field.",
    )

    __properties: ClassVar[List[str]] = [
        "timestamp",
        "level",
        "requestId",
        "accountId",
        "callId",
        "message",
        "metadata",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LogResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if timestamp (nullable) is None
        # and model_fields_set contains the field
        if self.timestamp is None and "timestamp" in self.model_fields_set:
            _dict["timestamp"] = None

        # set to None if level (nullable) is None
        # and model_fields_set contains the field
        if self.level is None and "level" in self.model_fields_set:
            _dict["level"] = None

        # set to None if request_id (nullable) is None
        # and model_fields_set contains the field
        if self.request_id is None and "request_id" in self.model_fields_set:
            _dict["requestId"] = None

        # set to None if account_id (nullable) is None
        # and model_fields_set contains the field
        if self.account_id is None and "account_id" in self.model_fields_set:
            _dict["accountId"] = None

        # set to None if call_id (nullable) is None
        # and model_fields_set contains the field
        if self.call_id is None and "call_id" in self.model_fields_set:
            _dict["callId"] = None

        # set to None if message (nullable) is None
        # and model_fields_set contains the field
        if self.message is None and "message" in self.model_fields_set:
            _dict["message"] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict["metadata"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LogResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "timestamp": obj.get("timestamp"),
                "level": obj.get("level"),
                "requestId": obj.get("requestId"),
                "accountId": obj.get("accountId"),
                "callId": obj.get("callId"),
                "message": obj.get("message"),
                "metadata": obj.get("metadata"),
            }
        )
        return _obj



import unittest

from freeclimb.utils.signature_information import SignatureInformation


class TestSignatureInformation(unittest.TestCase):
    """SignatureInformation unit test stubs"""

    def setUp(self):
        request_header = "t=1679944186,v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        self.signature_information = SignatureInformation(request_header)

    def tearDown(self):
        pass

    def test_is_request_time_valid_true(self):
        request_header = (
            "t="
            + str(self.signature_information.get_current_unix_time())
            + ",v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        )
        self.signature_information = SignatureInformation(request_header)
        tolerance = 5 * 60 * 1000
        self.assertEqual(
            self.signature_information.is_request_time_valid(tolerance), True
        )

    def test_is_request_time_valid_false(self):
        request_header = (
            "t="
            + str(
                self.signature_information.get_current_unix_time() - (600 * 60 * 1000)
            )
            + ",v1=c3957749baf61df4b1506802579cc69a74c77a1ae21447b930e5a704f9ec4120,v1=1ba18712726898fbbe48cd862dd096a709f7ad761a5bab14bda9ac24d963a6a8"
        )
        self.signature_information = SignatureInformation(request_header)
        tolerance = 500 * 60 * 1000
        self.assertEqual(
            self.signature_information.is_request_time_valid(tolerance), False
        )

    def test_is_signature_safe_true(self):
        request_body = '{"accountId":"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c","callId":"CAccb0b00506553cda09b51c5477f672a49e0b2213","callStatus":"ringing","conferenceId":null,"direction":"inbound","from":"+13121000109","parentCallId":null,"queueId":null,"requestType":"inboundCall","to":"+13121000096"}'
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7793"
        self.assertEqual(
            self.signature_information.is_signature_safe(request_body, signing_secret),
            True,
        )

    def test_is_signature_safe_false(self):
        request_body = '{"accountId":"AC1334ffb694cd8d969f51cddf5f7c9b478546d50c","callId":"CAccb0b00506553cda09b51c5477f672a49e0b2213","callStatus":"ringing","conferenceId":null,"direction":"inbound","from":"+13121000109","parentCallId":null,"queueId":null,"requestType":"inboundCall","to":"+13121000096"}'
        signing_secret = "sigsec_ead6d3b6904196c60835d039e91b3341c77a7794"
        self.assertEqual(
            self.signature_information.is_signature_safe(request_body, signing_secret),
            False,
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from freeclimb.models.sms_ten_dlc_partner_campaign_brand import (
    SMSTenDLCPartnerCampaignBrand,
)
from freeclimb.models.sms_ten_dlc_partner_campaign_status import (
    SMSTenDLCPartnerCampaignStatus,
)
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class SMSTenDLCPartnerCampaign(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    SMSTenDLCPartnerCampaign
    """  # noqa: E501

    account_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the account that created this Queue.",
        alias="accountId",
    )
    campaign_id: StrictStr = Field(
        description="Alphanumeric identifier assigned by the registry for a campaign. This identifier is required by the NetNumber OSR SMS enabling process of 10DLC.",
        alias="campaignId",
    )
    status: Optional[SMSTenDLCPartnerCampaignStatus] = None
    create_date: Optional[datetime] = Field(
        default=None,
        description="Unix timestamp when campaign was created.",
        alias="createDate",
    )
    brand_id: Annotated[str, Field(strict=True, max_length=8)] = Field(
        description="Alphanumeric identifier of the brand associated with this campaign.",
        alias="brandId",
    )
    usecase: Annotated[str, Field(strict=True, max_length=20)] = Field(
        description="Campaign usecase. Must be of defined valid types. Use `/registry/enum/usecase` operation to retrieve usecases available for given brand."
    )
    description: Annotated[str, Field(strict=True, max_length=4096)] = Field(
        description="Summary description of this campaign."
    )
    embedded_link: Optional[StrictBool] = Field(
        default=False,
        description="Does message generated by the campaign include URL link in SMS?",
        alias="embeddedLink",
    )
    embedded_phone: Optional[StrictBool] = Field(
        default=False,
        description="Does message generated by the campaign include phone number in SMS?",
        alias="embeddedPhone",
    )
    affiliate_marketing: Optional[StrictBool] = Field(
        default=None,
        description="Does message content controlled by affiliate marketing other than the brand?",
        alias="affiliateMarketing",
    )
    number_pool: Optional[StrictBool] = Field(
        default=False,
        description="Does campaign utilize pool of phone nubers?",
        alias="numberPool",
    )
    age_gated: Optional[StrictBool] = Field(
        default=None, description="Age gated content in campaign.", alias="ageGated"
    )
    direct_lending: Optional[StrictBool] = Field(default=None, alias="directLending")
    subscriber_optin: Optional[StrictBool] = Field(
        default=False,
        description="Does campaign require subscriber to opt-in before SMS is sent to subscriber?",
        alias="subscriberOptin",
    )
    subscriber_optout: Optional[StrictBool] = Field(
        default=False,
        description="Does campaign support subscriber opt-out keyword(s)?",
        alias="subscriberOptout",
    )
    subscriber_help: Optional[StrictBool] = Field(
        default=False,
        description="Does campaign responds to help keyword(s)?",
        alias="subscriberHelp",
    )
    sample1: Optional[Annotated[str, Field(strict=True, max_length=1024)]] = Field(
        default=None,
        description="Message sample. Some campaign tiers require 1 or more message samples.",
    )
    sample2: Optional[Annotated[str, Field(strict=True, max_length=1024)]] = Field(
        default=None,
        description="Message sample. Some campaign tiers require 2 or more message samples.",
    )
    sample3: Optional[Annotated[str, Field(strict=True, max_length=1024)]] = Field(
        default=None,
        description="Message sample. Some campaign tiers require 3 or more message samples.",
    )
    sample4: Optional[Annotated[str, Field(strict=True, max_length=1024)]] = Field(
        default=None,
        description="Message sample. Some campaign tiers require 4 or more message samples.",
    )
    sample5: Optional[Annotated[str, Field(strict=True, max_length=1024)]] = Field(
        default=None,
        description="Message sample. Some campaign tiers require 5 or more message samples.",
    )
    message_flow: Optional[Annotated[str, Field(strict=True, max_length=2048)]] = Field(
        default=None, description="Message flow description.", alias="messageFlow"
    )
    help_message: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(
        default=None, description="Help message of the campaign.", alias="helpMessage"
    )
    optin_keywords: Optional[Annotated[str, Field(strict=True, max_length=255)]] = (
        Field(
            default=None,
            description="Subscriber opt-in keywords. Multiple keywords are comma separated without space.",
            alias="optinKeywords",
        )
    )
    optout_keywords: Optional[Annotated[str, Field(strict=True, max_length=255)]] = (
        Field(
            default=None,
            description="Subscriber opt-out keywords. Multiple keywords are comma separated without space.",
            alias="optoutKeywords",
        )
    )
    help_keywords: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(
        default=None,
        description="Subscriber help keywords. Multiple keywords are comma separated without space.",
        alias="helpKeywords",
    )
    optin_message: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(
        default=None, description="Subscriber opt-in message.", alias="optinMessage"
    )
    optout_message: Optional[Annotated[str, Field(strict=True, max_length=255)]] = (
        Field(
            default=None,
            description="Subscriber opt-out message.",
            alias="optoutMessage",
        )
    )
    brand: Optional[SMSTenDLCPartnerCampaignBrand] = None

    __properties: ClassVar[List[str]] = [
        "accountId",
        "campaignId",
        "status",
        "createDate",
        "brandId",
        "usecase",
        "description",
        "embeddedLink",
        "embeddedPhone",
        "affiliateMarketing",
        "numberPool",
        "ageGated",
        "directLending",
        "subscriberOptin",
        "subscriberOptout",
        "subscriberHelp",
        "sample1",
        "sample2",
        "sample3",
        "sample4",
        "sample5",
        "messageFlow",
        "helpMessage",
        "optinKeywords",
        "optoutKeywords",
        "helpKeywords",
        "optinMessage",
        "optoutMessage",
        "brand",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SMSTenDLCPartnerCampaign from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of brand
        if self.brand:
            _dict["brand"] = self.brand.to_dict()
        # set to None if account_id (nullable) is None
        # and model_fields_set contains the field
        if self.account_id is None and "account_id" in self.model_fields_set:
            _dict["accountId"] = None

        # set to None if sample2 (nullable) is None
        # and model_fields_set contains the field
        if self.sample2 is None and "sample2" in self.model_fields_set:
            _dict["sample2"] = None

        # set to None if sample3 (nullable) is None
        # and model_fields_set contains the field
        if self.sample3 is None and "sample3" in self.model_fields_set:
            _dict["sample3"] = None

        # set to None if sample4 (nullable) is None
        # and model_fields_set contains the field
        if self.sample4 is None and "sample4" in self.model_fields_set:
            _dict["sample4"] = None

        # set to None if sample5 (nullable) is None
        # and model_fields_set contains the field
        if self.sample5 is None and "sample5" in self.model_fields_set:
            _dict["sample5"] = None

        # set to None if message_flow (nullable) is None
        # and model_fields_set contains the field
        if self.message_flow is None and "message_flow" in self.model_fields_set:
            _dict["messageFlow"] = None

        # set to None if help_message (nullable) is None
        # and model_fields_set contains the field
        if self.help_message is None and "help_message" in self.model_fields_set:
            _dict["helpMessage"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SMSTenDLCPartnerCampaign from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "accountId": obj.get("accountId"),
                "campaignId": obj.get("campaignId"),
                "status": obj.get("status"),
                "createDate": obj.get("createDate"),
                "brandId": obj.get("brandId"),
                "usecase": obj.get("usecase"),
                "description": obj.get("description"),
                "embeddedLink": (
                    obj.get("embeddedLink")
                    if obj.get("embeddedLink") is not None
                    else False
                ),
                "embeddedPhone": (
                    obj.get("embeddedPhone")
                    if obj.get("embeddedPhone") is not None
                    else False
                ),
                "affiliateMarketing": obj.get("affiliateMarketing"),
                "numberPool": (
                    obj.get("numberPool")
                    if obj.get("numberPool") is not None
                    else False
                ),
                "ageGated": obj.get("ageGated"),
                "directLending": obj.get("directLending"),
                "subscriberOptin": (
                    obj.get("subscriberOptin")
                    if obj.get("subscriberOptin") is not None
                    else False
                ),
                "subscriberOptout": (
                    obj.get("subscriberOptout")
                    if obj.get("subscriberOptout") is not None
                    else False
                ),
                "subscriberHelp": (
                    obj.get("subscriberHelp")
                    if obj.get("subscriberHelp") is not None
                    else False
                ),
                "sample1": obj.get("sample1"),
                "sample2": obj.get("sample2"),
                "sample3": obj.get("sample3"),
                "sample4": obj.get("sample4"),
                "sample5": obj.get("sample5"),
                "messageFlow": obj.get("messageFlow"),
                "helpMessage": obj.get("helpMessage"),
                "optinKeywords": obj.get("optinKeywords"),
                "optoutKeywords": obj.get("optoutKeywords"),
                "helpKeywords": obj.get("helpKeywords"),
                "optinMessage": obj.get("optinMessage"),
                "optoutMessage": obj.get("optoutMessage"),
                "brand": (
                    SMSTenDLCPartnerCampaignBrand.from_dict(obj["brand"])
                    if obj.get("brand") is not None
                    else None
                ),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class QueueMember(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    QueueMember
    """  # noqa: E501

    uri: Optional[StrictStr] = Field(
        default=None,
        description="URI for this Queue Member resource, relative to the API base URL.",
    )
    call_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the Call associated with this Queue Member.",
        alias="callId",
    )
    wait_time: Optional[StrictInt] = Field(
        default=None,
        description="Number of seconds the Member has been in the queue.",
        alias="waitTime",
    )
    position: Optional[StrictInt] = Field(
        default=None, description="Member's current position in the Queue, 1 indexed."
    )
    date_enqueued: Optional[StrictStr] = Field(
        default=None,
        description="Date that the Member was enqueued (GMT), given in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).",
        alias="dateEnqueued",
    )

    __properties: ClassVar[List[str]] = [
        "uri",
        "callId",
        "waitTime",
        "position",
        "dateEnqueued",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of QueueMember from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if uri (nullable) is None
        # and model_fields_set contains the field
        if self.uri is None and "uri" in self.model_fields_set:
            _dict["uri"] = None

        # set to None if call_id (nullable) is None
        # and model_fields_set contains the field
        if self.call_id is None and "call_id" in self.model_fields_set:
            _dict["callId"] = None

        # set to None if wait_time (nullable) is None
        # and model_fields_set contains the field
        if self.wait_time is None and "wait_time" in self.model_fields_set:
            _dict["waitTime"] = None

        # set to None if position (nullable) is None
        # and model_fields_set contains the field
        if self.position is None and "position" in self.model_fields_set:
            _dict["position"] = None

        # set to None if date_enqueued (nullable) is None
        # and model_fields_set contains the field
        if self.date_enqueued is None and "date_enqueued" in self.model_fields_set:
            _dict["dateEnqueued"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of QueueMember from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "uri": obj.get("uri"),
                "callId": obj.get("callId"),
                "waitTime": obj.get("waitTime"),
                "position": obj.get("position"),
                "dateEnqueued": obj.get("dateEnqueued"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.sms_ten_dlc_brand import SMSTenDLCBrand


class TestSMSTenDLCBrand(unittest.TestCase):
    """SMSTenDLCBrand unit test stubs"""

    def setUp(self):
        self.model = SMSTenDLCBrand(
            entity_type=SMSTenDLCBrandEntityType.PRIVATE_PROFIT,
            display_name="TS",
            phone="TS",
            country="TS",
            email="TS",
            brand_relationship=SMSTenDLCBrandRelationship.BASIC_ACCOUNT,
            vertical="TS",
            mock=True,
            identity_status=SMSTenDLCBrandIdentityStatus.SELF_DECLARED,
        )

    def test_account_id(self):
        """Test SMSTenDLCBrand.account_id"""

        self.model.account_id = "TEST_STRING"
        assert self.model.account_id == "TEST_STRING"

    def test_entity_type(self):
        """Test SMSTenDLCBrand.entity_type"""
        self.model.entity_type = SMSTenDLCBrandEntityType.PRIVATE_PROFIT
        assert self.model.entity_type == SMSTenDLCBrandEntityType.PRIVATE_PROFIT
        self.model.entity_type = SMSTenDLCBrandEntityType.PUBLIC_PROFIT
        assert self.model.entity_type == SMSTenDLCBrandEntityType.PUBLIC_PROFIT
        self.model.entity_type = SMSTenDLCBrandEntityType.NON_PROFIT
        assert self.model.entity_type == SMSTenDLCBrandEntityType.NON_PROFIT
        self.model.entity_type = SMSTenDLCBrandEntityType.GOVERNMENT
        assert self.model.entity_type == SMSTenDLCBrandEntityType.GOVERNMENT
        self.model.entity_type = SMSTenDLCBrandEntityType.SOLE_PROPRIETOR
        assert self.model.entity_type == SMSTenDLCBrandEntityType.SOLE_PROPRIETOR

    def test_csp_id(self):
        """Test SMSTenDLCBrand.csp_id"""

        self.model.csp_id = "TEST_STRING"
        assert self.model.csp_id == "TEST_STRING"

    def test_brand_id(self):
        """Test SMSTenDLCBrand.brand_id"""

        self.model.brand_id = "TEST_STRING"
        assert self.model.brand_id == "TEST_STRING"

    def test_first_name(self):
        """Test SMSTenDLCBrand.first_name"""
        self.model.first_name = "T" * 100
        assert self.model.first_name == "T" * 100

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.first_name = "T" * (100 + 1)

    def test_last_name(self):
        """Test SMSTenDLCBrand.last_name"""
        self.model.last_name = "T" * 100
        assert self.model.last_name == "T" * 100

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.last_name = "T" * (100 + 1)

    def test_display_name(self):
        """Test SMSTenDLCBrand.display_name"""
        self.model.display_name = "T" * 255
        assert self.model.display_name == "T" * 255

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.display_name = "T" * (255 + 1)

    def test_company_name(self):
        """Test SMSTenDLCBrand.company_name"""
        self.model.company_name = "T" * 255
        assert self.model.company_name == "T" * 255

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.company_name = "T" * (255 + 1)

    def test_ein(self):
        """Test SMSTenDLCBrand.ein"""
        self.model.ein = "T" * 21
        assert self.model.ein == "T" * 21

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.ein = "T" * (21 + 1)

    def test_ein_issuing_country(self):
        """Test SMSTenDLCBrand.ein_issuing_country"""
        self.model.ein_issuing_country = "T" * 2
        assert self.model.ein_issuing_country == "T" * 2

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.ein_issuing_country = "T" * (2 + 1)

    def test_phone(self):
        """Test SMSTenDLCBrand.phone"""
        self.model.phone = "T" * 20
        assert self.model.phone == "T" * 20

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.phone = "T" * (20 + 1)

    def test_street(self):
        """Test SMSTenDLCBrand.street"""
        self.model.street = "T" * 100
        assert self.model.street == "T" * 100

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.street = "T" * (100 + 1)

    def test_city(self):
        """Test SMSTenDLCBrand.city"""
        self.model.city = "T" * 100
        assert self.model.city == "T" * 100

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.city = "T" * (100 + 1)

    def test_state(self):
        """Test SMSTenDLCBrand.state"""
        self.model.state = "T" * 20
        assert self.model.state == "T" * 20

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.state = "T" * (20 + 1)

    def test_postal_code(self):
        """Test SMSTenDLCBrand.postal_code"""
        self.model.postal_code = "T" * 10
        assert self.model.postal_code == "T" * 10

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.postal_code = "T" * (10 + 1)

    def test_country(self):
        """Test SMSTenDLCBrand.country"""
        self.model.country = "T" * 2
        assert self.model.country == "T" * 2

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.country = "T" * (2 + 1)

    def test_email(self):
        """Test SMSTenDLCBrand.email"""
        self.model.email = "T" * 100
        assert self.model.email == "T" * 100

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.email = "T" * (100 + 1)

    def test_stock_symbol(self):
        """Test SMSTenDLCBrand.stock_symbol"""
        self.model.stock_symbol = "T" * 10
        assert self.model.stock_symbol == "T" * 10

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.stock_symbol = "T" * (10 + 1)

    def test_stock_exchange(self):
        """Test SMSTenDLCBrand.stock_exchange"""
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.NONE
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.NONE
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.NASDAQ
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.NASDAQ
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.NYSE
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.NYSE
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.AMEX
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.AMEX
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.AMX
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.AMX
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.ASX
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.ASX
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.B3
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.B3
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.BME
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.BME
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.BSE
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.BSE
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.FRA
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.FRA
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.ICEX
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.ICEX
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.JPX
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.JPX
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.JSE
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.JSE
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.KRX
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.KRX
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.LON
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.LON
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.NSE
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.NSE
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.OMX
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.OMX
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.SEHK
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.SEHK
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.SGX
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.SGX
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.SSE
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.SSE
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.STO
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.STO
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.SWX
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.SWX
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.SZSE
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.SZSE
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.TSX
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.TSX
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.TWSE
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.TWSE
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.VSE
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.VSE
        self.model.stock_exchange = SMSTenDLCBrandStockExchange.OTHER
        assert self.model.stock_exchange == SMSTenDLCBrandStockExchange.OTHER

    def test_ip_address(self):
        """Test SMSTenDLCBrand.ip_address"""
        self.model.ip_address = "T" * 50
        assert self.model.ip_address == "T" * 50

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.ip_address = "T" * (50 + 1)

    def test_website(self):
        """Test SMSTenDLCBrand.website"""
        self.model.website = "T" * 100
        assert self.model.website == "T" * 100

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.website = "T" * (100 + 1)

    def test_brand_relationship(self):
        """Test SMSTenDLCBrand.brand_relationship"""
        self.model.brand_relationship = SMSTenDLCBrandRelationship.BASIC_ACCOUNT
        assert self.model.brand_relationship == SMSTenDLCBrandRelationship.BASIC_ACCOUNT
        self.model.brand_relationship = SMSTenDLCBrandRelationship.SMALL_ACCOUNT
        assert self.model.brand_relationship == SMSTenDLCBrandRelationship.SMALL_ACCOUNT
        self.model.brand_relationship = SMSTenDLCBrandRelationship.MEDIUM_ACCOUNT
        assert (
            self.model.brand_relationship == SMSTenDLCBrandRelationship.MEDIUM_ACCOUNT
        )
        self.model.brand_relationship = SMSTenDLCBrandRelationship.LARGE_ACCOUNT
        assert self.model.brand_relationship == SMSTenDLCBrandRelationship.LARGE_ACCOUNT
        self.model.brand_relationship = SMSTenDLCBrandRelationship.KEY_ACCOUNT
        assert self.model.brand_relationship == SMSTenDLCBrandRelationship.KEY_ACCOUNT

    def test_vertical(self):
        """Test SMSTenDLCBrand.vertical"""
        self.model.vertical = "T" * 50
        assert self.model.vertical == "T" * 50

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.vertical = "T" * (50 + 1)

    def test_alt_business_id(self):
        """Test SMSTenDLCBrand.alt_business_id"""
        self.model.alt_business_id = "T" * 50
        assert self.model.alt_business_id == "T" * 50

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.alt_business_id = "T" * (50 + 1)

    def test_alt_business_id_type(self):
        """Test SMSTenDLCBrand.alt_business_id_type"""
        self.model.alt_business_id_type = SMSTenDLCBrandAltBusinessIdType.NONE
        assert self.model.alt_business_id_type == SMSTenDLCBrandAltBusinessIdType.NONE
        self.model.alt_business_id_type = SMSTenDLCBrandAltBusinessIdType.DUNS
        assert self.model.alt_business_id_type == SMSTenDLCBrandAltBusinessIdType.DUNS
        self.model.alt_business_id_type = SMSTenDLCBrandAltBusinessIdType.GIIN
        assert self.model.alt_business_id_type == SMSTenDLCBrandAltBusinessIdType.GIIN
        self.model.alt_business_id_type = SMSTenDLCBrandAltBusinessIdType.LEI
        assert self.model.alt_business_id_type == SMSTenDLCBrandAltBusinessIdType.LEI

    def test_universal_ein(self):
        """Test SMSTenDLCBrand.universal_ein"""

        self.model.universal_ein = "TEST_STRING"
        assert self.model.universal_ein == "TEST_STRING"

    def test_reference_id(self):
        """Test SMSTenDLCBrand.reference_id"""
        self.model.reference_id = "T" * 50
        assert self.model.reference_id == "T" * 50

        with self.assertRaises(pydantic_core._pydantic_core.ValidationError) as info:
            self.model.reference_id = "T" * (50 + 1)

    def test_optional_attributes(self):
        """Test SMSTenDLCBrand.optional_attributes"""
        object = {}
        self.model.optional_attributes = object
        assert self.model.optional_attributes == object

    def test_mock(self):
        """Test SMSTenDLCBrand.mock"""
        self.model.mock = False
        assert self.model.mock == False

    def test_identity_status(self):
        """Test SMSTenDLCBrand.identity_status"""
        self.model.identity_status = SMSTenDLCBrandIdentityStatus.SELF_DECLARED
        assert self.model.identity_status == SMSTenDLCBrandIdentityStatus.SELF_DECLARED
        self.model.identity_status = SMSTenDLCBrandIdentityStatus.UNVERIFIED
        assert self.model.identity_status == SMSTenDLCBrandIdentityStatus.UNVERIFIED
        self.model.identity_status = SMSTenDLCBrandIdentityStatus.VERIFIED
        assert self.model.identity_status == SMSTenDLCBrandIdentityStatus.VERIFIED
        self.model.identity_status = SMSTenDLCBrandIdentityStatus.VETTED_VERIFIED
        assert (
            self.model.identity_status == SMSTenDLCBrandIdentityStatus.VETTED_VERIFIED
        )

    def test_create_date(self):
        """Test SMSTenDLCBrand.create_date"""
        self.model.create_date = datetime.fromtimestamp(1691592436)
        assert self.model.create_date == datetime.fromtimestamp(1691592436)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.call_direction import CallDirection
from freeclimb.models.call_status import CallStatus
from freeclimb.models.conference_status import ConferenceStatus
from freeclimb.models.webhook import Webhook
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class CreateConferenceWebhook(
    Webhook, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    A Conference has been created and its statusCallbackUrl or actionUrl is being invoked. A PerCL response is expected if the actionUrl is being invoked.
    """  # noqa: E501

    request_type: Optional[StrictStr] = Field(
        default=None,
        description="Context or reason why this request is being made. Will be createConference - A Conference has been created and its statusCallbackUrl or actionUrl is being invoked.",
        alias="requestType",
    )
    call_id: Optional[StrictStr] = Field(
        default=None,
        description="Unique ID for this Call, generated by FreeClimb.",
        alias="callId",
    )
    account_id: Optional[StrictStr] = Field(
        default=None,
        description="Account ID associated with your account.",
        alias="accountId",
    )
    var_from: Optional[StrictStr] = Field(
        default=None,
        description="Phone number of the party that initiated the Call (in E.164 format).",
        alias="from",
    )
    to: Optional[StrictStr] = Field(
        default=None,
        description="Phone number provisioned to you and to which this Call is directed (in E.164 format).",
    )
    call_status: Optional[CallStatus] = Field(default=None, alias="callStatus")
    direction: Optional[CallDirection] = None
    conference_id: Optional[StrictStr] = Field(
        default=None, description="Unique ID of the Conference.", alias="conferenceId"
    )
    queue_id: Optional[StrictStr] = Field(
        default=None,
        description="This is only populated if the request pertains to a Queue. Otherwise, it is set to null.",
        alias="queueId",
    )
    status: Optional[ConferenceStatus] = None
    recording_url: Optional[StrictStr] = Field(
        default=None,
        description="The URL of the Conference’s recorded audio. Populated only if a Recording exists and the Conference was emptied. Present only if statusCallbackUrl is being invoked.",
        alias="recordingUrl",
    )
    recording_id: Optional[StrictStr] = Field(
        default=None,
        description="The unique ID of the Recording from this Conference. Populated only if a Recording exists and the Conference was emptied. Present only if statusCallbackUrl is being invoked.",
        alias="recordingId",
    )
    recording_duration_sec: Optional[StrictInt] = Field(
        default=None,
        description="The duration of the recorded audio rounded up to the nearest second (in seconds). Populated only if a Recording exists and the Conference was emptied. Present only if statusCallbackUrl is being invoked.",
        alias="recordingDurationSec",
    )

    __properties: ClassVar[List[str]] = [
        "requestType",
        "callId",
        "accountId",
        "from",
        "to",
        "callStatus",
        "direction",
        "conferenceId",
        "queueId",
        "status",
        "recordingUrl",
        "recordingId",
        "recordingDurationSec",
    ]

    @classmethod
    def deserialize(cls, payload: str) -> Optional[Self]:
        return cls.from_json(payload)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateConferenceWebhook from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if call_status (nullable) is None
        # and model_fields_set contains the field
        if self.call_status is None and "call_status" in self.model_fields_set:
            _dict["callStatus"] = None

        # set to None if direction (nullable) is None
        # and model_fields_set contains the field
        if self.direction is None and "direction" in self.model_fields_set:
            _dict["direction"] = None

        # set to None if queue_id (nullable) is None
        # and model_fields_set contains the field
        if self.queue_id is None and "queue_id" in self.model_fields_set:
            _dict["queueId"] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict["status"] = None

        # set to None if recording_url (nullable) is None
        # and model_fields_set contains the field
        if self.recording_url is None and "recording_url" in self.model_fields_set:
            _dict["recordingUrl"] = None

        # set to None if recording_id (nullable) is None
        # and model_fields_set contains the field
        if self.recording_id is None and "recording_id" in self.model_fields_set:
            _dict["recordingId"] = None

        # set to None if recording_duration_sec (nullable) is None
        # and model_fields_set contains the field
        if (
            self.recording_duration_sec is None
            and "recording_duration_sec" in self.model_fields_set
        ):
            _dict["recordingDurationSec"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateConferenceWebhook from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "requestType": obj.get("requestType"),
                "callId": obj.get("callId"),
                "accountId": obj.get("accountId"),
                "from": obj.get("from"),
                "to": obj.get("to"),
                "callStatus": obj.get("callStatus"),
                "direction": obj.get("direction"),
                "conferenceId": obj.get("conferenceId"),
                "queueId": obj.get("queueId"),
                "status": obj.get("status"),
                "recordingUrl": obj.get("recordingUrl"),
                "recordingId": obj.get("recordingId"),
                "recordingDurationSec": obj.get("recordingDurationSec"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.capabilities import Capabilities
from freeclimb.models.tfn import TFN
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class IncomingNumberResult(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    IncomingNumberResult
    """  # noqa: E501

    uri: Optional[StrictStr] = Field(
        default=None, description="The URI for this resource, relative to /apiserver."
    )
    date_created: Optional[StrictStr] = Field(
        default=None,
        description="The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).",
        alias="dateCreated",
    )
    date_updated: Optional[StrictStr] = Field(
        default=None,
        description="The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).",
        alias="dateUpdated",
    )
    revision: Optional[StrictInt] = Field(
        default=None,
        description="Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.",
    )
    capabilities: Optional[Capabilities] = None
    campaign_id: Optional[StrictStr] = Field(
        default=None,
        description="The campaign ID generated by the campaign registry",
        alias="campaignId",
    )
    phone_number_id: Optional[StrictStr] = Field(
        default=None,
        description="String that uniquely identifies this phone number resource.",
        alias="phoneNumberId",
    )
    account_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the account that owns this phone number.",
        alias="accountId",
    )
    application_id: Optional[StrictStr] = Field(
        default=None,
        description="ID of the Application that FreeClimb should contact if a Call or SMS arrives for this phone number or a Call from this number is placed. An incoming phone number is not useful until associated with an applicationId.",
        alias="applicationId",
    )
    phone_number: Optional[StrictStr] = Field(
        default=None, description="Phone number in E.164 format.", alias="phoneNumber"
    )
    alias: Optional[StrictStr] = Field(
        default=None,
        description="Description for this phone number. Typically the conventionally-formatted version of the phone number.",
    )
    region: Optional[StrictStr] = Field(
        default=None, description="State or province of this phone number."
    )
    country: Optional[StrictStr] = Field(
        default=None, description="Country of this phone number."
    )
    voice_enabled: Optional[StrictBool] = Field(
        default=None,
        description="Indicates whether the phone number can handle Calls. Typically set to true for all numbers.",
        alias="voiceEnabled",
    )
    sms_enabled: Optional[StrictBool] = Field(
        default=None,
        description="Indication of whether the phone number can handle sending and receiving SMS messages. Typically set to true for all numbers.",
        alias="smsEnabled",
    )
    offnet: Optional[StrictBool] = Field(
        default=None,
        description="The offnet field is a boolean representing whether the number is offnet registered or not. This field will be rendered only for requests to the IncomingPhone number resource.",
    )
    tfn: Optional[TFN] = None

    __properties: ClassVar[List[str]] = [
        "uri",
        "dateCreated",
        "dateUpdated",
        "revision",
        "capabilities",
        "campaignId",
        "phoneNumberId",
        "accountId",
        "applicationId",
        "phoneNumber",
        "alias",
        "region",
        "country",
        "voiceEnabled",
        "smsEnabled",
        "offnet",
        "tfn",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IncomingNumberResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of capabilities
        if self.capabilities:
            _dict["capabilities"] = self.capabilities.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tfn
        if self.tfn:
            _dict["tfn"] = self.tfn.to_dict()
        # set to None if campaign_id (nullable) is None
        # and model_fields_set contains the field
        if self.campaign_id is None and "campaign_id" in self.model_fields_set:
            _dict["campaignId"] = None

        # set to None if phone_number_id (nullable) is None
        # and model_fields_set contains the field
        if self.phone_number_id is None and "phone_number_id" in self.model_fields_set:
            _dict["phoneNumberId"] = None

        # set to None if account_id (nullable) is None
        # and model_fields_set contains the field
        if self.account_id is None and "account_id" in self.model_fields_set:
            _dict["accountId"] = None

        # set to None if application_id (nullable) is None
        # and model_fields_set contains the field
        if self.application_id is None and "application_id" in self.model_fields_set:
            _dict["applicationId"] = None

        # set to None if phone_number (nullable) is None
        # and model_fields_set contains the field
        if self.phone_number is None and "phone_number" in self.model_fields_set:
            _dict["phoneNumber"] = None

        # set to None if alias (nullable) is None
        # and model_fields_set contains the field
        if self.alias is None and "alias" in self.model_fields_set:
            _dict["alias"] = None

        # set to None if region (nullable) is None
        # and model_fields_set contains the field
        if self.region is None and "region" in self.model_fields_set:
            _dict["region"] = None

        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict["country"] = None

        # set to None if voice_enabled (nullable) is None
        # and model_fields_set contains the field
        if self.voice_enabled is None and "voice_enabled" in self.model_fields_set:
            _dict["voiceEnabled"] = None

        # set to None if sms_enabled (nullable) is None
        # and model_fields_set contains the field
        if self.sms_enabled is None and "sms_enabled" in self.model_fields_set:
            _dict["smsEnabled"] = None

        # set to None if offnet (nullable) is None
        # and model_fields_set contains the field
        if self.offnet is None and "offnet" in self.model_fields_set:
            _dict["offnet"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IncomingNumberResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "uri": obj.get("uri"),
                "dateCreated": obj.get("dateCreated"),
                "dateUpdated": obj.get("dateUpdated"),
                "revision": obj.get("revision"),
                "capabilities": (
                    Capabilities.from_dict(obj["capabilities"])
                    if obj.get("capabilities") is not None
                    else None
                ),
                "campaignId": obj.get("campaignId"),
                "phoneNumberId": obj.get("phoneNumberId"),
                "accountId": obj.get("accountId"),
                "applicationId": obj.get("applicationId"),
                "phoneNumber": obj.get("phoneNumber"),
                "alias": obj.get("alias"),
                "region": obj.get("region"),
                "country": obj.get("country"),
                "voiceEnabled": obj.get("voiceEnabled"),
                "smsEnabled": obj.get("smsEnabled"),
                "offnet": obj.get("offnet"),
                "tfn": (
                    TFN.from_dict(obj["tfn"]) if obj.get("tfn") is not None else None
                ),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.get_speech import GetSpeech


class TestGetSpeech(unittest.TestCase):
    """GetSpeech unit test stubs"""

    def setUp(self):
        self.model = GetSpeech(
            action_url="TS",
            grammar_file="TS",
        )

    def test_action_url(self):
        """Test GetSpeech.action_url"""
        self.model.action_url = "TEST_STRING"
        assert self.model.action_url == "TEST_STRING"

    def test_grammar_type(self):
        """Test GetSpeech.grammar_type"""
        self.model.grammar_type = GrammarType.URL
        assert self.model.grammar_type == GrammarType.URL
        self.model.grammar_type = GrammarType.BUILT_IN
        assert self.model.grammar_type == GrammarType.BUILT_IN

    def test_grammar_file(self):
        """Test GetSpeech.grammar_file"""

        self.model.grammar_file = "TEST_STRING"
        assert self.model.grammar_file == "TEST_STRING"

    def test_grammar_rule(self):
        """Test GetSpeech.grammar_rule"""

        self.model.grammar_rule = "TEST_STRING"
        assert self.model.grammar_rule == "TEST_STRING"

    def test_play_beep(self):
        """Test GetSpeech.play_beep"""
        self.model.play_beep = False
        assert self.model.play_beep == False

    def test_prompts(self):
        """Test GetSpeech.prompts"""
        testList = []
        self.model.prompts = testList
        assert self.model.prompts == testList

    def test_no_input_timeout_ms(self):
        """Test GetSpeech.no_input_timeout_ms"""
        self.model.no_input_timeout_ms = 1
        assert self.model.no_input_timeout_ms == 1

    def test_recognition_timeout_ms(self):
        """Test GetSpeech.recognition_timeout_ms"""
        self.model.recognition_timeout_ms = 1
        assert self.model.recognition_timeout_ms == 1

    def test_confidence_threshold(self):
        """Test GetSpeech.confidence_threshold"""

        self.model.confidence_threshold = float(1)
        assert self.model.confidence_threshold == float(1)

    def test_sensitivity_level(self):
        """Test GetSpeech.sensitivity_level"""

        self.model.sensitivity_level = float(1)
        assert self.model.sensitivity_level == float(1)

    def test_speech_complete_timeout_ms(self):
        """Test GetSpeech.speech_complete_timeout_ms"""
        self.model.speech_complete_timeout_ms = 1
        assert self.model.speech_complete_timeout_ms == 1

    def test_speech_incomplete_timeout_ms(self):
        """Test GetSpeech.speech_incomplete_timeout_ms"""
        self.model.speech_incomplete_timeout_ms = 1
        assert self.model.speech_incomplete_timeout_ms == 1

    def test_privacy_mode(self):
        """Test GetSpeech.privacy_mode"""
        self.model.privacy_mode = False
        assert self.model.privacy_mode == False


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from freeclimb.models.percl_command import PerclCommand
from freeclimb.models.play_beep import PlayBeep
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class CreateConference(
    PerclCommand,
    populate_by_name=True,
    validate_assignment=True,
    protected_namespaces=(),
):
    """
    The `CreateConference` command does exactly what its name implies — it creates an unpopulated Conference (one without any Participants). Once created, a Conference remains in FreeClimb until explicitly terminated by a customer. Once a Conference has been terminated, it can no longer be used.
    """  # noqa: E501

    action_url: StrictStr = Field(
        description=" This URL is invoked once the Conference is successfully created. Actions on the Conference, such as adding Participants, can be performed via the PerCL script returned in the response. ",
        alias="actionUrl",
    )
    alias: Optional[StrictBool] = Field(
        default=None, description="Descriptive name for the Conference. "
    )
    play_beep: Optional[PlayBeep] = Field(default=None, alias="playBeep")
    record: Optional[StrictBool] = Field(
        default=None,
        description="When set to `true`, the entire Conference is recorded. The `statusCallbackUrl` of the Conference will receive a `conferenceRecordingEnded` Webhook when the Conference transitions from the `inProgress` to empty state.",
    )
    status_callback_url: Optional[StrictStr] = Field(
        default=None,
        description="This URL is invoked when the status of the Conference changes or when a recording of the Conference has become available.",
        alias="statusCallbackUrl",
    )
    wait_url: Optional[StrictStr] = Field(
        default=None,
        description="If specified, this URL provides the custom hold music for the Conference when it is in the populated state. This attribute is always fetched using HTTP GET and is fetched just once – when the Conference is created. The URL must be an audio file that is reachable and readable by FreeClimb.",
        alias="waitUrl",
    )
    command: StrictStr = "CreateConference"

    __properties: ClassVar[List[str]] = [
        "command",
        "actionUrl",
        "alias",
        "playBeep",
        "record",
        "statusCallbackUrl",
        "waitUrl",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateConference from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if play_beep (nullable) is None
        # and model_fields_set contains the field
        if self.play_beep is None and "play_beep" in self.model_fields_set:
            _dict["playBeep"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateConference from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "command": obj.get("command"),
                "actionUrl": obj.get("actionUrl"),
                "alias": obj.get("alias"),
                "playBeep": obj.get("playBeep"),
                "record": obj.get("record"),
                "statusCallbackUrl": obj.get("statusCallbackUrl"),
                "waitUrl": obj.get("waitUrl"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class MessageRequest(
    BaseModel, populate_by_name=True, validate_assignment=True, protected_namespaces=()
):
    """
    MessageRequest
    """  # noqa: E501

    uri: Optional[StrictStr] = Field(
        default=None, description="The URI for this resource, relative to /apiserver."
    )
    date_created: Optional[StrictStr] = Field(
        default=None,
        description="The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).",
        alias="dateCreated",
    )
    date_updated: Optional[StrictStr] = Field(
        default=None,
        description="The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).",
        alias="dateUpdated",
    )
    revision: Optional[StrictInt] = Field(
        default=None,
        description="Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.",
    )
    var_from: StrictStr = Field(
        description="Phone number to use as the sender. This must be an incoming phone number that you have purchased from FreeClimb.",
        alias="from",
    )
    to: StrictStr = Field(
        description="Phone number to receive the message. Must be within FreeClimb's service area."
    )
    text: StrictStr = Field(
        description="Text contained in the message (maximum 160 characters).   **Note:** For text, only ASCII characters are supported."
    )
    notification_url: Optional[StrictStr] = Field(
        default=None,
        description="When the Message changes status, this URL is invoked using HTTP POST with the messageStatus parameters.  **Note:** This is a notification only; any PerCL returned is ignored.",
        alias="notificationUrl",
    )
    media_urls: Optional[List[StrictStr]] = Field(
        default=None,
        description="an array of HTTP URLs which are to be used as attachments to the message. This will force the message into being an MMS message and must be done using a from number which is MMS capabile.",
        alias="mediaUrls",
    )

    __properties: ClassVar[List[str]] = [
        "uri",
        "dateCreated",
        "dateUpdated",
        "revision",
        "from",
        "to",
        "text",
        "notificationUrl",
        "mediaUrls",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MessageRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if media_urls (nullable) is None
        # and model_fields_set contains the field
        if self.media_urls is None and "media_urls" in self.model_fields_set:
            _dict["mediaUrls"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MessageRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "uri": obj.get("uri"),
                "dateCreated": obj.get("dateCreated"),
                "dateUpdated": obj.get("dateUpdated"),
                "revision": obj.get("revision"),
                "from": obj.get("from"),
                "to": obj.get("to"),
                "text": obj.get("text"),
                "notificationUrl": obj.get("notificationUrl"),
                "mediaUrls": obj.get("mediaUrls"),
            }
        )
        return _obj



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.out_dial_connect_webhook import OutDialConnectWebhook


class TestOutDialConnectWebhook(unittest.TestCase):
    """OutDialConnectWebhook unit test stubs"""

    def setUp(self):
        self.model = OutDialConnectWebhook()

    def test_request_type(self):
        """Test OutDialConnectWebhook.request_type"""

    def test_account_id(self):
        """Test OutDialConnectWebhook.account_id"""

        self.model.account_id = "TEST_STRING"
        assert self.model.account_id == "TEST_STRING"

    def test_call_id(self):
        """Test OutDialConnectWebhook.call_id"""

        self.model.call_id = "TEST_STRING"
        assert self.model.call_id == "TEST_STRING"

    def test_var_from(self):
        """Test OutDialConnectWebhook.var_from"""

        self.model.var_from = "TEST_STRING"
        assert self.model.var_from == "TEST_STRING"

    def test_to(self):
        """Test OutDialConnectWebhook.to"""

        self.model.to = "TEST_STRING"
        assert self.model.to == "TEST_STRING"

    def test_call_status(self):
        """Test OutDialConnectWebhook.call_status"""
        self.model.call_status = CallStatus.QUEUED
        assert self.model.call_status == CallStatus.QUEUED
        self.model.call_status = CallStatus.RINGING
        assert self.model.call_status == CallStatus.RINGING
        self.model.call_status = CallStatus.IN_PROGRESS
        assert self.model.call_status == CallStatus.IN_PROGRESS
        self.model.call_status = CallStatus.CANCELED
        assert self.model.call_status == CallStatus.CANCELED
        self.model.call_status = CallStatus.COMPLETED
        assert self.model.call_status == CallStatus.COMPLETED
        self.model.call_status = CallStatus.FAILED
        assert self.model.call_status == CallStatus.FAILED
        self.model.call_status = CallStatus.BUSY
        assert self.model.call_status == CallStatus.BUSY
        self.model.call_status = CallStatus.NO_ANSWER
        assert self.model.call_status == CallStatus.NO_ANSWER

    def test_direction(self):
        """Test OutDialConnectWebhook.direction"""
        self.model.direction = CallDirection.INBOUND
        assert self.model.direction == CallDirection.INBOUND
        self.model.direction = CallDirection.OUTBOUND_API
        assert self.model.direction == CallDirection.OUTBOUND_API
        self.model.direction = CallDirection.OUTBOUND_DIAL
        assert self.model.direction == CallDirection.OUTBOUND_DIAL

    def test_conference_id(self):
        """Test OutDialConnectWebhook.conference_id"""

        self.model.conference_id = "TEST_STRING"
        assert self.model.conference_id == "TEST_STRING"

    def test_queue_id(self):
        """Test OutDialConnectWebhook.queue_id"""

        self.model.queue_id = "TEST_STRING"
        assert self.model.queue_id == "TEST_STRING"

    def test_parent_call_id(self):
        """Test OutDialConnectWebhook.parent_call_id"""

        self.model.parent_call_id = "TEST_STRING"
        assert self.model.parent_call_id == "TEST_STRING"

    def test_deserialize(self):
        payload = '{ "requestType": "outDialConnect" }'
        assert isinstance(
            OutDialConnectWebhook.deserialize(payload), OutDialConnectWebhook
        )


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from freeclimb.models.grammar_type import GrammarType
from freeclimb.models.percl_command import PerclCommand
from pydantic import StrictStr
from typing import Optional, Set
from typing_extensions import Self


class GetSpeech(
    PerclCommand,
    populate_by_name=True,
    validate_assignment=True,
    protected_namespaces=(),
):
    """
    The `GetSpeech` command enables the Caller to respond to the application using a supported language. Unlike DTMF entry, which implicitly restricts the user to using the available buttons on the phone key pad, speech input allows for flexible audio inputs based on grammar. FreeClimb supports grammars written using GRXML compatible with the Microsoft Speech Platform. `GetSpeech` is only supported on a single call leg. It is not supported when there are two or more call legs connected (as in within a Conference).
    """  # noqa: E501

    action_url: StrictStr = Field(
        description="When the caller has finished speaking or the command has timed out, FreeClimb will make a POST request to this URL. A PerCL response is expected to continue handling the call.",
        alias="actionUrl",
    )
    grammar_type: Optional[GrammarType] = Field(default=None, alias="grammarType")
    grammar_file: StrictStr = Field(
        description="The grammar file to use for speech recognition. If grammarType is set to URL, this attribute is specified as a download URL.",
        alias="grammarFile",
    )
    grammar_rule: Optional[StrictStr] = Field(
        default=None,
        description="The grammar rule within the specified grammar file to use for speech recognition. This attribute is optional if `grammarType` is `URL` and ignored if `grammarType` is `BUILTIN`.",
        alias="grammarRule",
    )
    play_beep: Optional[StrictBool] = Field(
        default=None,
        description="Indicates whether a beep should be played just before speech recognition is initiated so that the speaker can start to speak.",
        alias="playBeep",
    )
    prompts: Optional[List[PerclCommand]] = Field(
        default=None,
        description="The JSON array of PerCL commands to nest within the `GetSpeech` command. The `Say`, `Play`, and `Pause` commands can be used. The nested actions are executed while FreeClimb is waiting for input from the caller. This allows for playing menu options to the caller and to prompt for the expected input. These commands stop executing when the caller begins to input speech.",
    )
    no_input_timeout_ms: Optional[StrictInt] = Field(
        default=None,
        description="When recognition is started and there is no speech detected for `noInputTimeoutMs` milliseconds, the recognizer will terminate the recognition operation.",
        alias="noInputTimeoutMs",
    )
    recognition_timeout_ms: Optional[StrictInt] = Field(
        default=None,
        description="When playback of prompts ends and there is no match for `recognitionTimeoutMs` milliseconds, the recognizer will terminate the recognition operation.",
        alias="recognitionTimeoutMs",
    )
    confidence_threshold: Optional[Union[StrictFloat, StrictInt]] = Field(
        default=None,
        description="When a recognition resource recognizes a spoken phrase, it associates a confidence level with that match. Parameter `confidenceThreshold` specifies what confidence level is considered a successful match. Values are between 0.0 and 1.0.",
        alias="confidenceThreshold",
    )
    sensitivity_level: Optional[Union[StrictFloat, StrictInt]] = Field(
        default=None,
        description="The speech recognizer supports a variable level of sound sensitivity. The sensitivityLevel attribute allows for filtering out background noise, so it is not mistaken for speech. Values are between 0.0 and 1.0 ",
        alias="sensitivityLevel",
    )
    speech_complete_timeout_ms: Optional[StrictInt] = Field(
        default=None,
        description="Parameter `speechCompleteTimeoutMs` specifies the length of silence required following user speech before the speech recognizer finalizes a result. This timeout applies when the recognizer currently has a complete match against an active grammar. Reasonable speech complete timeout values are typically in the range of 0.3 seconds to 1.0 seconds.",
        alias="speechCompleteTimeoutMs",
    )
    speech_incomplete_timeout_ms: Optional[StrictInt] = Field(
        default=None,
        description="Parameter `speechIncompleteTimeoutMs` specifies the length of silence following user speech after which a recognizer finalizes a result. This timeout applies when the speech prior to the silence is an incomplete match of all active grammars. Timeout `speechIncompleteTimeoutMs` is usually longer than `speechCompleteTimeoutMs` to allow users to pause mid-utterance.",
        alias="speechIncompleteTimeoutMs",
    )
    privacy_mode: Optional[StrictBool] = Field(
        default=None,
        description="Parameter privacyMode will not log the `text` as required by PCI compliance.",
        alias="privacyMode",
    )
    command: StrictStr = "GetSpeech"

    __properties: ClassVar[List[str]] = [
        "command",
        "actionUrl",
        "grammarType",
        "grammarFile",
        "grammarRule",
        "playBeep",
        "prompts",
        "noInputTimeoutMs",
        "recognitionTimeoutMs",
        "confidenceThreshold",
        "sensitivityLevel",
        "speechCompleteTimeoutMs",
        "speechIncompleteTimeoutMs",
        "privacyMode",
    ]

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GetSpeech from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in prompts (list)
        _items = []
        if self.prompts:
            for _item_prompts in self.prompts:
                if _item_prompts:
                    _items.append(_item_prompts.to_dict())
            _dict["prompts"] = _items
        # set to None if grammar_type (nullable) is None
        # and model_fields_set contains the field
        if self.grammar_type is None and "grammar_type" in self.model_fields_set:
            _dict["grammarType"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GetSpeech from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "command": obj.get("command"),
                "actionUrl": obj.get("actionUrl"),
                "grammarType": obj.get("grammarType"),
                "grammarFile": obj.get("grammarFile"),
                "grammarRule": obj.get("grammarRule"),
                "playBeep": obj.get("playBeep"),
                "prompts": (
                    [PerclCommand.from_dict(_item) for _item in obj["prompts"]]
                    if obj.get("prompts") is not None
                    else None
                ),
                "noInputTimeoutMs": obj.get("noInputTimeoutMs"),
                "recognitionTimeoutMs": obj.get("recognitionTimeoutMs"),
                "confidenceThreshold": obj.get("confidenceThreshold"),
                "sensitivityLevel": obj.get("sensitivityLevel"),
                "speechCompleteTimeoutMs": obj.get("speechCompleteTimeoutMs"),
                "speechIncompleteTimeoutMs": obj.get("speechIncompleteTimeoutMs"),
                "privacyMode": obj.get("privacyMode"),
            }
        )
        return _obj
